==> haskell-tamarin-prover-export-1.10.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-5za4jIUnesNEurqFbdXV4P
key:                  tamarin-prover-export-1.10.0-5za4jIUnesNEurqFbdXV4P
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  8f508cca6f072c9728ab3422860e5e73
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-5za4jIUnesNEurqFbdXV4P
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-JeN0T0supUMcQ7an9Zim0
    tamarin-prover-term-1.10.0-DEFp9rAj3laDIQ9tvOzZxX
    tamarin-prover-theory-1.10.0-1HzFdSPFpNa4l79EgXyuie
    tamarin-prover-utils-1.10.0-rYrRQel2BNK48sNvZ4NDC text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.10.0-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-4LJiQ3AoAPm2S3xHwtCny9
key:                  tamarin-prover-export-1.10.0-4LJiQ3AoAPm2S3xHwtCny9
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  5448331fc95b49e00c9d9c9909a9ac79
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-4LJiQ3AoAPm2S3xHwtCny9
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-I7UxDnkVc8kKvylbZFHPe1
    tamarin-prover-term-1.10.0-C0J2Nw0dwEK2xBkhlzfRPZ
    tamarin-prover-theory-1.10.0-5Zb0rtxYPtb1g5jzUGxm1P
    tamarin-prover-utils-1.10.0-6bGs1ghwythK9e5psrKm1k text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
